Function fetch_and_process_partial_note_completion_logs
pub unconstrained fn fetch_and_process_partial_note_completion_logs<Env>(
contract_address: AztecAddress,
compute_note_hash_and_nullifier: ComputeNoteHashAndNullifier<Env>,
)
pub unconstrained fn fetch_and_process_partial_note_completion_logs<Env>(
contract_address: AztecAddress,
compute_note_hash_and_nullifier: ComputeNoteHashAndNullifier<Env>,
)
Searches for logs that would result in the completion of pending partial notes, ultimately resulting in the notes being delivered to PXE if completed.